pub struct Ligature<'a> {
data: FontData<'a>,
}Expand description
Part of LigatureSubstFormat1
Fields
data: FontData<'a>Implementations
Sourceimpl<'a> Ligature<'a>
impl<'a> Ligature<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn ligature_glyph(&self) -> GlyphId16
pub fn ligature_glyph(&self) -> GlyphId16
glyph ID of ligature to substitute
Sourcepub fn component_count(&self) -> u16
pub fn component_count(&self) -> u16
Number of components in the ligature
Sourcepub fn component_glyph_ids(&self) -> &'a [BigEndian<GlyphId16>]
pub fn component_glyph_ids(&self) -> &'a [BigEndian<GlyphId16>]
Array of component glyph IDs — start with the second component, ordered in writing direction
pub fn ligature_glyph_byte_range(&self) -> Range<usize> ⓘ
pub fn component_count_byte_range(&self) -> Range<usize> ⓘ
pub fn component_glyph_ids_byte_range(&self) -> Range<usize> ⓘ