pub struct SingleSubstFormat2<'a> {
data: FontData<'a>,
}Expand description
Fields
data: FontData<'a>Implementations
Sourceimpl<'a> SingleSubstFormat2<'a>
impl<'a> SingleSubstFormat2<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn subst_format(&self) -> u16
pub fn subst_format(&self) -> u16
Format identifier: format = 2
Sourcepub fn coverage_offset(&self) -> Offset16
pub fn coverage_offset(&self) -> Offset16
Offset to Coverage table, from beginning of substitution subtable
Sourcepub fn coverage(&self) -> Result<CoverageTable<'a>, ReadError>
pub fn coverage(&self) -> Result<CoverageTable<'a>, ReadError>
Attempt to resolve coverage_offset.
Sourcepub fn glyph_count(&self) -> u16
pub fn glyph_count(&self) -> u16
Number of glyph IDs in the substituteGlyphIDs array
Sourcepub fn substitute_glyph_ids(&self) -> &'a [BigEndian<GlyphId16>]
pub fn substitute_glyph_ids(&self) -> &'a [BigEndian<GlyphId16>]
Array of substitute glyph IDs — ordered by Coverage index
pub fn subst_format_byte_range(&self) -> Range<usize> ⓘ
pub fn coverage_offset_byte_range(&self) -> Range<usize> ⓘ
pub fn glyph_count_byte_range(&self) -> Range<usize> ⓘ
pub fn substitute_glyph_ids_byte_range(&self) -> Range<usize> ⓘ